load healthdata

%% Grouped scatter plot
figure
gscatter(data.Height,data.Weight,data.Sex,'br','.',5)
xlabel('Height [cm]'), ylabel('Weight [kg]')

%% Grouped plot matrix
%  Extract data
bmeas = double(data(:,11:16));
hw = double(data(:,8:9));
figure

%  Make grouped plot matrix.  Vanilla version:
%  gplotmatrix(bmeas,hw,data.Sex)

%  Create cell arrays for labels
bmeaslabels = data.Properties.VarNames(11:16);
hwlabels = data.Properties.VarNames(8:9);
%  Specify colors, markers, size (default), legend (on), plots on
%  diagonals (default = scatter), and axis labels
gplotmatrix(bmeas,hw,data.Sex,'br','.',[],'on','',bmeaslabels,hwlabels)

%% Boxplot
%  Calculate difference in actual vs reported weight/height
dw = data.Weight-data.ReportWeight/2.2046226;   % kg
dh = data.Height-data.ReportHeight*2.54;        % cm
%  View differences in weight, grouped by sex
figure
boxplot(dw,data.Sex)
ylabel('\Delta weight [kg]')
%  Add horizontal line at y = 0
line(xlim,[0,0],'linestyle','--','color','k')
%  Can zoom in vertically:
%  ylim([-10,10])

%% Grouped summary statistics
%  Calculate means, grouped by sex
mns = grpstats([dw,dh],data.Sex)
%  More stats (std, median, iqr)
[devs,meds,iqrs] = grpstats([dw,dh],data.Sex,{'std',@median,@iqr})

%% Grouping using logical variables
figure
gscatter(data.Height,data.Weight,data.Waist>100,'br','.',5)
xlabel('Height [cm]'), ylabel('Weight [kg]')
legend('Waist \leq 100 cm','Waist > 100 cm')
